import argparse
from svglob import glob


parser = argparse.ArgumentParser(description=glob.__doc__)
parser.add_argument('files', nargs='+', help='The SVG files to process.')
parser.add_argument('--suffix', default='.glob', help='Text to add to the end of the file name (default: .glob).')

args = parser.parse_args()
for file in args.files:
    try:
        new_file = glob(file, args.suffix)
        print(file, '->', new_file)
    except Exception as e:
        print('ERROR:', file, e.split('\n')[0])



from svgpathtools import svg2paths, wsvg, Path


def glob(file, suffix):
    '''Combine SVG paths into one compound path.'''
    paths, _, svg_attributes = svg2paths(file, return_svg_attributes=True)
    compound = Path(*[segment for path in paths for segment in path])
    new_file = file[:-4] + suffix + file[-4:]
    wsvg(compound, svg_attributes=svg_attributes, filename=new_file)
    return new_file
